@@ -104,7 +104,9 @@ def main():
         help="key name of the elapsed_time in the log file",
     )
     parser.add_argument(
-        "--key-of-interest", help="log key of interest",
+        "--key-of-interest",
+        default=default_args.pop("key_of_interest", None),
+        help="log key of interest",
     )
     args = parser.parse_args()
 
