@@ -105,27 +105,31 @@ def parse(
 
             key = "{} (max)".format(col)
             log_keys.add(key)
-            if key_of_interest is None:
-                index = log[col].idxmax()
-            else:
-                index = log[key_of_interest].idxmax()
-            if math.isnan(index):
-                continue
-            datum[key] = (
-                log[col][index],
-                (log[key_epoch][index], log[key_iteration][index]),
-            )
+            index = log[col].idxmax()
+            if key_of_interest is not None:
+                if key_of_interest.endswith(" (max)"):
+                    index = log[key_of_interest[:-6]].idxmax()
+                elif key_of_interest.endswith(" (min)"):
+                    index = log[key_of_interest[:-6]].idxmin()
+            if not math.isnan(index):
+                datum[key] = (
+                    log[col][index],
+                    (log[key_epoch][index], log[key_iteration][index]),
+                )
 
             key = "{} (min)".format(col)
             log_keys.add(key)
-            if key_of_interest is None:
-                index = log[col].idxmin()
-            else:
-                index = log[key_of_interest].idxmax()
-            datum[key] = (
-                log[col][index],
-                (log[key_epoch][index], log[key_iteration][index]),
-            )
+            index = log[col].idxmax()
+            if key_of_interest is not None:
+                if key_of_interest.endswith(" (max)"):
+                    index = log[key_of_interest[:-6]].idxmax()
+                elif key_of_interest.endswith(" (min)"):
+                    index = log[key_of_interest[:-6]].idxmin()
+            if not math.isnan(index):
+                datum[key] = (
+                    log[col][index],
+                    (log[key_epoch][index], log[key_iteration][index]),
+                )
 
         data.append(datum)
 
